//
//  SMAConfiguration.h
//  SmaatoSDKCore
//
//  Created by Maksym Cherniaiev on 10/07/2018.
//  Copyright © 2018 Smaato Inc. All rights reserved.
//

#import <SmaatoSDKCore/SMALoggerConfiguration.h>

/**
 A configuration that is used to initialize the SDK.
 */
@interface SMAConfiguration : NSObject

/**
 Set this flag to YES to require secure creatives.
 Secure creative is a creative for which responses have links with HTTPS scheme only and links that redirect to HTTPS only.

 Default value is reflecting ATS settings (true when ATS is enabled, false otherwise), when \c httpsOnly accessor is called before setter.
 In such case, setting \c httpsOnly to different value is not possible anymore.

 @note Setting this flag may get overridden because of your application's Application Transport Security settings,
       so if ATS is enabled and you set this flag to NO, the final value of flag will be YES.
       Alternatively, setting this flag to YES or NO, while ATS is disabled, will be respected.
 */
@property (nonatomic) BOOL httpsOnly;

/**
 If this property is not changed, default logging level is \c kSMALogLevelInfo
 */
@property (nonatomic) SMALogLevel logLevel;

/**
 Set this property to YES if you want to disable log messages from SDK
 */
@property (nonatomic) BOOL loggingDisabled;

@end
