//
//  SmaatoSDK+HeaderBidding.h
//  SmaatoSDKHeaderBidding
//
//  Created by Denisia Enasescu on 28/01/2019.
//  Copyright © 2019 Siarhei Barmotska. All rights reserved.
//

#import <SmaatoSDKCore/SmaatoSDKCore.h>

@interface SmaatoSDK (HeaderBidding)

/**
 The method starts the SmaatoSDK HeaderBidding module

 Current HeaderBidding module is optional and works only with MopubSDK, when SmaatoSDK is included as secondary with all required adapters

 @warning This method must be called once
 @param publisherId Publisher HB identifier assigned by Smaato. Must not be \c nil.
*/
+ (void)enableHeaderBiddingWithPublisherId:(NSString *_Nonnull)publisherId;

/**
 The method prepares prebid request for Banner or Interstitial or RewardedVideo ads

 Current HeaderBidding module works only with MopubSDK, then expected adObject could be `MPAdView` or `MPInterstitialAdController` or class
 object of `MPRewardedVideo`

 @param adObject `MPAdView` or `MPInterstitialAdController` or `MPRewardedVideo` class instance which should be prepared with  Smaato key,
 before final Mopub `loadAd()` call. Must not be \c nil.
 @param adSpaceId AdspaceId identifier assigned by Smaato. HeaderBidding support should be enabled for this AdspaceId in Smaato SPX. Must
 not be \c nil
 @param completion Completion callback is invoked, when adObject is updated with Smaato PreBid price. `bidSuccess` and `error` values
 reflect state of PreBid request. Must not be \c nil.
 */
+ (void)applyPreBidKeyForAdObject:(id _Nonnull)adObject
                        adSpaceId:(NSString *_Nonnull)adSpaceId
                       completion:(void (^_Nonnull)(BOOL success, NSError *error))completion;

@end
